@@ -21,12 +21,12 @@ except ImportError:
 from bitmaptools import draw_line, fill_region
 from ulab import numpy as np
 
-__version__ = "0.9.4"
+__version__ = "0.10.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
 # pylint: disable=too-many-arguments, invalid-name, no-self-use, too-few-public-methods
-# pylint: disable=too-many-locals, too-many-branches, protected-access
+# pylint: disable=too-many-locals, too-many-branches, protected-access, unnecessary-list-index-lookup
 class ulogging:
     """
     Class to log data
@@ -42,6 +42,8 @@ class ulogging:
         line_color: int = 0xFFFFFF,
         ticksx: Union[np.array, list] = np.array([0, 10, 30, 50, 70, 90]),
         ticksy: Union[np.array, list] = np.array([0, 10, 30, 50, 70, 90]),
+        tick_pos: bool = False,
+        fill: bool = False,
     ) -> None:
         """
 
@@ -53,11 +55,20 @@ class ulogging:
         :param int|None line_color: line color. Defaults to None
         :param np.array|list ticksx: X axis ticks values
         :param np.array|list ticksy: Y axis ticks values
+        :param bool tick_pos: indicates ticks position. True for below the axes.
+         Defaults to ``False``
+        :param bool fill: enable the filling of the plot. Defaults to ``False``
 
         """
         self.points = []
         self.ticksx = np.array(ticksx)
         self.ticksy = np.array(ticksy)
+        if tick_pos:
+            self._tickposx = plot._tickheightx
+            self._tickposy = plot._tickheighty
+        else:
+            self._tickposx = 0
+            self._tickposy = 0
 
         plot._plot_palette[plot._index_colorused] = line_color
 
@@ -101,6 +112,17 @@ class ulogging:
                     ynorm[index + 1],
                     plot._index_colorused,
                 )
+            if fill:
+                for index, _ in enumerate(xnorm):
+                    draw_line(
+                        plot._plotbitmap,
+                        xnorm[index],
+                        ynorm[index],
+                        xnorm[index],
+                        plot._newymin,
+                        plot._index_colorused,
+                    )
+
         if plot._showticks:
             if plot._loggingfirst:
                 self._draw_ticks(plot)
@@ -130,9 +152,9 @@ class ulogging:
             draw_line(
                 plot._plotbitmap,
                 tick,
-                plot._newymin,
+                plot._newymin + self._tickposx,
                 tick,
-                plot._newymin - plot._tickheightx,
+                plot._newymin - plot._tickheightx + self._tickposx,
                 2,
             )
             if plot._showtext:
@@ -142,9 +164,9 @@ class ulogging:
         for i, tick in enumerate(ticksynorm):
             draw_line(
                 plot._plotbitmap,
-                plot._newxmin,
+                plot._newxmin - self._tickposy,
                 tick,
-                plot._newxmin + plot._tickheighty,
+                plot._newxmin + plot._tickheighty - self._tickposy,
                 tick,
                 2,
             )
